@@ -2,10 +2,9 @@
 import requests
 
 
-def request_accesstoken(acc, pwd):
+def request_accesstoken(acc: str, pwd: str) -> str:
     # 请求accesstooke函数
     url = "http://bms.microc.cn/shopguide/api/auth/logon"
-    # url = "http://test.xxynet.com/shopguide/api/auth/logon"
     data = {}
     data["loginName"] = acc
     data["password"] = pwd
@@ -15,23 +14,19 @@ def request_accesstoken(acc, pwd):
         # print(response.json())
         accessToken = response.json().get("accessToken")
         return accessToken
-    else:
-        raise ValueError("用户名或密码错误。")
 
 
 class base:
-    def __init__(self, token, app_secret):
+    def __init__(self, token, app_secret=None):
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name, data, method="GET"):
-        '''
-        公共请求方法：
-        '''
+    def request(self, api_name=None, data={}, method="GET", url=None):
         host_name = "http://bms.microc.cn/shopguide/api/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
-        if host_name not in api_name:
-            url = f"{host_name}{api_name}"
+        if not url:
+            if host_name not in api_name:
+                url = f"{host_name}{api_name}"
 
         if "accessToken" not in data:
             # 没有token自动添加
@@ -42,9 +37,14 @@ class base:
 
         if method == "GET":
             response = requests.get(url, params=data)
-        else:
+        elif method == "POST":
             response = requests.post(url, data=data)
-
+        else:
+            raise ValueError("请求方法错误。")
+        # print(url, response.status_code)
         if response.status_code == 200:
-            # print(data,response.json())
-            return response.json()
+            # print(data, response.json())
+            return self.response(response.json())
+
+    def response(self, response_raw):
+        return response_raw
